@@ -21,22 +21,22 @@ if __name__ == '__main__':
     NO_UNITS = [0,0,0,0,0]
     ALL_UNITS = [-1,-1,-1,-1,-1]
 
-    B = Army(units_land = [0,0,0,0,0], 
-             units_air =  [0,0,0,1,0], 
-             units_sea =  [2,0,0,0,0],
+    B = Army(units_land = [3,0,0,0,0], 
+             units_air =  [0,0,0,0,0], 
+             units_sea =  [0,0,0,0,0],
              options = config)
-    B.apply_stance(stance_land = [NO_UNITS,    ALL_UNITS],
+    B.apply_stance(stance_land = [ALL_UNITS,    NO_UNITS],
                     stance_air = [NO_UNITS,    ALL_UNITS],
                     stance_sea = [NO_UNITS,    ALL_UNITS])
 
 
-    A = Army(units_land = [0,0,0,0,0], 
+    A = Army(units_land = [3,2,0,0,0], 
              units_air =  [0,0,0,0,0], 
-             units_sea =  [3,0,0,0,0],
+             units_sea =  [0,0,0,0,0],
              options = config)
 
-    A.apply_stance(stance_land = [NO_UNITS, ALL_UNITS],
-                    stance_air = [NO_UNITS,      ALL_UNITS],
+    A.apply_stance(stance_land = [NO_UNITS,     ALL_UNITS],
+                    stance_air = [NO_UNITS,     ALL_UNITS],
                     stance_sea = [ALL_UNITS,    NO_UNITS])
     
     sim = Simulate(None, None)
